@@ -1,9 +1,11 @@
-''''''
+""""""
 
 import irt_parameter_estimation
 
+
 def test_1():
     pass
 
-if __name__ == '__main__':
-    test_1()
\ No newline at end of file
+
+if __name__ == "__main__":
+    test_1()
